title: Stab a Book, the Book Won't Die
url: https://craigmod.com/essays/media_accounting/
hash_url: 4f4dfee4677038df8e39c5547ed8adeb

<p>How do we account for the resilient nature of books? They&rsquo;re not dead, though according to a hundred years of prognostications of their demise, they should be.</p>

<p>To understand why books are still around, and why they delight as they do, we need to do some &ldquo;media accounting&rdquo; — What are the costs (individually, socially) of engaging with certain media and mediums, apps and publications?</p>

<p>Understanding the contracts into which we enter with media helps demystify why physical books (and, similarly, vinyl, analog film, et cetera) not only remain compelling, but become <em>more</em> compelling the more their digital twins grow vast and fuzzy.</p>

<p>This essay is just a cursory document. A light expansion on a lecture I gave at Yale for the 2019 <a href="https://som.yale.edu/programs/executive-education/for-individuals/leadership/yale-publishing-course">Yale Publishing Course</a>.</p>

<hr />

<h3 id="books">Books</h3>

<p>Let&rsquo;s begin with printed books.</p>

<p>Printed books have clear contracts. I&rsquo;ve written about this in passing before, over in <a href="https://craigmod.com/ridgeline/030/"><em>Ridgeline</em></a>:</p>

<blockquote>
<p>We buy a book, we know what we’re getting. There is no other “business model” at play. No other information being (necessarily, relatively) sold. This clarity of contract is especially lucid in physical form. The book has edges. The transaction has edges. The transaction completes. Given time, we complete the book. It has an ending. Contracts are clear. Usually, there’s no tracking.</p>
</blockquote>

<p>A printed book is an object over which no third party has agency once in your possession. It&rsquo;s protected (in the US, at least) by <a href="https://en.wikipedia.org/wiki/First-sale_doctrine">first sale doctrine</a>.  Digital books, not to the same degree. Amazon, for example, <a href="https://www.nytimes.com/2009/07/18/technology/companies/18amazon.html">famously deleted editions of “1984”</a> from everyone’s Kindles. Simultaneously, today (2019), courts in France are <a href="https://www.tomshardware.com/news/valve-steam-resell-games-ban-france-eu,40438.html">challenging the general inability to resell digital goods</a>.</p>

<p>The immutability of printed books is their superpower. Remember this, because it&rsquo;s from this immutability that books derive their dead-simple &ldquo;contract.&rdquo;</p>

<hr />

<h3 id="attention-monsters-things-that-eat-attention">Attention Monsters: Things that Eat Attention</h3>

<p>The main adversary of books and book publishing is: Anything that eats attention.</p>

<p>Publishing has always been a game of competing for attention. Any number of media inventions have <a href="https://www.theparisreview.org/blog/2019/09/17/books-wont-die/">threatened to eviscerate the book market</a>: radio, movies, television, et cetera. But smartphones tip the scales unlike any previous object. They do so by placing into our pockets a perfect, always-at-hand vector for &ldquo;lopsided user contracts,&rdquo; arriving in the form of apps and websites.</p>

<p>These suboptimal contracts are at their most exaggeratedly worst in what I call “attention monsters.” That is, any app / service / publication whose business is predicated on keeping a consumer engaged and re-engaged for the benefit of the organization (often to the detriment of the mental and physical health of the user), dozens if not hundreds or thousands of times a day.</p>

<p>A simple heuristic for determining if something is an attention monster: “Free” apps built around advertising models <em>tend</em> to become attention monsters.<sup class="footnote-ref" id="fnref:adapps"><a href="#fn:adapps">1</a></sup> Especially if they’ve taken on a lot of venture capital, a tendency even further exacerbated if they’re a public company.<sup class="footnote-ref" id="fnref:venture"><a href="#fn:venture">2</a></sup></p>

<p>Instagram is a great example. The more you scroll, the more money they make. Consider the &ldquo;agreement&rdquo; into which you&rsquo;ve entered with the application the next time you find yourself mindlessly scrolling. What’s keeping you there? Why are the algorithms showing you what they’e showing? What benefits are you accruing? Why do you feel the need to post what you&rsquo;re posting? For what are are you trading your time and mental energy?</p>

<p>Most likely, you&rsquo;re stuck in a <a href="https://craigmod.com/roden/027/">&ldquo;tiny loop:&rdquo;</a></p>

<blockquote>
<p>— a senseless series of actions that span minutes, hours, days, consume years, and add up to nothing or almost nothing, and that benefit (ideally: tranquility, growth, curiosity) no one but the company (in reality: engagement, ad views) who owns the container in which the loop takes place.<sup class="footnote-ref" id="fnref:bigloops"><a href="#fn:bigloops">3</a></sup></p>
</blockquote>

<p>Because of a need to show consistent growth over time, <a href="https://arxiv.org/pdf/1907.07032.pdf#targetText=Dark%20patterns%20are%20user%20interface,a%20large%20set%20of%20websites.">attention monster methods of consuming user attention</a> become more aggressive the larger the user base becomes. A once simple contract (“connect with your friends online,” “post photos with cool filters,” et cetera) into which we may have entered with a free app begins to change by small degrees when that app or publication is pushed to increase profitability.<sup class="footnote-ref" id="fnref:founders"><a href="#fn:founders">4</a></sup></p>

<p>As a grossly-simplified counter example: Consider almost any piece of open source software. The version control software <a href="https://en.wikipedia.org/wiki/Git">&lsquo;Git&rsquo;</a> is used by hundreds of millions of people, as are Apache and nginx web servers, but none of these examples contains user experience dark patterns, nor are they concerned with consuming attention.</p>

<hr />

<p>Apps that feed off of and grow based on attention are often <a href="http://sitn.hms.harvard.edu/flash/2018/dopamine-smartphones-battle-time/">dopaminergic</a>. They are built to amplify <a href="https://www.sciencedaily.com/releases/2017/02/170222131508.htm">reward seeking behavior</a>, releasing unpredictable hits of dopamine: Another like. A DM. A new QAnon video in a sidebar. A &ldquo;related article&rdquo; about vaccination dangers. Something — anything — to increase engagement time in service to ad revenue.</p>

<hr />

<h3 id="publications-are-different-from-books">Publications (are different from books)</h3>

<p>Publications also fall into this bucket.</p>

<p><em>The New York Times</em>  is a partially dopaminergic publication. That is, the success of it as a business is still contingent on readers looking at a lot of ads. It’s also dependent on subscriptions, which is why the writing is usually high-caliber; quality is necessary to convert casual readers into subscribers (hyperbole is necessary to multiply ad views); becoming a subscriber is often a proxy vote for quality.</p>

<p>But the <em>Times</em> makes a <a href="https://www.nytimes.com/2019/08/07/business/media/new-york-times-earnings.html">significant portion of its profits</a> from ads, so eating your attention is still good for the organism. Hence, click-bait headlines. And horrible, horrible election needles: real-time &ldquo;content machinery&rdquo; adjacent to ads from which you can’t avert your gaze. Of course, <em>The Times</em> is not the only publication that functions like this. Most legacy or incumbent news organizations do, too.</p>

<hr />

<p>When these incumbent newspapers were print only, there was only one way to &ldquo;enter&rdquo; the content: Through the front page. The front page was all you could see on the news stand. Once you bought the thing, you were converted to a paying participant.</p>

<p>Make note: <strong>Design and contract parameters go hand in hand.</strong> When the front page is the only entry point, only a single page of the publication requires hyperbole to convert passers-by to readers. Online, every article becomes a potential entry point. And so there is an incentive for pervasive hyperbole in order to “convert” eyeballs in service to ads and the consumption of more attention.</p>

<hr />

<p>In contrast, publications like <a href="https://www.theinformation.com/"><em>The Information</em></a> or <a href="https://stratechery.com/"><em>Stratechery</em></a> or <a href="https://newconsumer.com/"><em>The New Consumer</em></a> — recently founded publications — are (almost?) entirely subscriber based, and thereby shed themselves of attention gorging.<sup class="footnote-ref" id="fnref:adsok"><a href="#fn:adsok">5</a></sup></p>

<p>The contract a reader enters with <em>The Information</em> is very clear: We pay, they write. Enough of us pay so they can keep writing. They write in a way that provides value via knowledge (ostensibly leading to smarter business decisions or investments on the part of the reader; i.e., extremely clear value proposition), not shock. Their model is <em>not</em> contingent on us looking at their writing from morning until night. Once a day is more than enough. Entry points are limited. It’s a healthy model for all parties.</p>

<p>As <em>The Information</em> says on their about page:</p>

<blockquote>
<p>Quality stories breed quality subscribers. As our subscriber community grows, we&rsquo;re investing aggressively in our team and reporting. We believe this formula is far more scalable than relying on traffic or conferences, and it&rsquo;s totally—100 percent—aligned with our readers.</p>
</blockquote>

<p>Our contract with <em>The New York Times</em> is more slippery. Yes, we pay and they write, but also, they take our viewing patterns, biases, reading habits, estimated income and sell that to advertisers. That’s a weirder contract. And one into which most people don’t realize they’ve entered. <sup class="footnote-ref" id="fnref:unintendedcontracts"><a href="#fn:unintendedcontracts">6</a></sup></p>

<p>All of this attention eating is relatively new. It is, as I said above, largely reliant on the smartphones in our pockets. The rise of attention monsters and this scale of attention consumption and lopsided contracts is one of many <a href="https://www.sas.upenn.edu/~haroldfs/540/handouts/french/unintconseq.html">unintended consequences</a> of the last ten years of internet growth and pocket supercomputers.</p>

<hr />

<h3 id="media-contracts">Media Contracts</h3>

<p>Consider the contracts of these two images.</p>

<p>People on a <a href="https://pixabay.com/photos/tokyo-asia-japan-human-metro-city-1536844/">train today</a>:</p>

<p><img src="/essays/images/media_accounting/subway_iphone.jpg" alt="staring at smartphones on a train" style="width: 100%; height: auto;" class="fullbleed" /></p>

<p>People on a train in Philadelphia <a href="https://www.gettyimages.co.jp/detail/%E3%83%8B%E3%83%A5%E3%83%BC%E3%82%B9%E5%86%99%E7%9C%9F/packed-carriage-on-a-commuter-train-in-philadelphia-%E3%83%8B%E3%83%A5%E3%83%BC%E3%82%B9%E5%86%99%E7%9C%9F/3436262?adppopup=true">65 years ago</a>:</p>

<p><img src="/roden/img/030/papertrain.jpg" alt="staring at newspapers on a train" style="width: 100%; height: auto;" class="fullbleed" /></p>

<p>Superficially these images look similar: folks committed to a horizontal surface held in front of their faces. But the contract of these two objects couldn’t be more different.</p>

<p><img src="/roden/img/030/newspaper.jpg" alt="bounded and boundless" style="width: 100%; height: auto;" class="fullbleed" /></p>

<p>The printed newspaper of 1919 had edges, ended. There were ads but they were passive, not active members of the reading experience. They were not reading you. You paid. You got some paper. The paper did not continue forever.</p>

<hr />

<p>Most readers may be too young to remember this, but once upon a time, <a href="https://craigmod.com/roden/img/030/broadcastdone.mp4">even television ended</a>. There was an implicit contract in that <em>eventually</em> you’d be allowed — nay, forced — to sleep. Like, you’d be watching some late-night show and the broadcast would just … finish. Kaput. The national anthem would blare and then the broadcast completion tone would wake any fools still perched in their living room Lay-Z-Boys.</p>

<video controls width="100%">
    <source src="/roden/img/030/broadcastdone.mp4" type="video/mp4" />
</video>

<hr />

<h3 id="netflix-vs-criterion">Netflix vs. Criterion</h3>

<p>Compare that era of television with opening the Netflix app.<sup class="footnote-ref" id="fnref:streaming"><a href="#fn:streaming">7</a></sup> CEO Reed Hastings: <a href="https://www.fastcompany.com/40491939/netflix-ceo-reed-hastings-sleep-is-our-competition">“Sleep is our competitor.”</a></p>

<p>Netflix<sup class="footnote-ref" id="fnref:netflix"><a href="#fn:netflix">8</a></sup> is a company with a 134 billion dollar market capitalization and 6,000+ employees. Competition is rapidly rising: Disney+, Amazon Prime, HBO Go / Now / MAX, Apple TV+. Netflix is a public company. They must continue to grow. Netflix can’t lose us as subscribers, <em>but</em> they also can’t charge much more. In fact, it&rsquo;s likely they&rsquo;ll have to reduce prices. And so, one imagines an internal doctrine: <em>Netflix must become a downtime habit humans cannot live without.</em> The service must become a teat, an irreplaceable and inexhaustible binge conveyance.<sup class="footnote-ref" id="fnref:appletv"><a href="#fn:appletv">9</a></sup> Unsubscribe? Unthinkable! Their current strategy in achieving this is to produce an endless profusion of well-funded shows. Some of which are superb. They produced <a href="https://variety.com/2018/digital/news/netflix-700-original-series-2018-1202711940/">700 — 7-0-0 — shows in 2018</a> alone.</p>

<hr />

<p>Compare now with <a href="https://www.criterionchannel.com/">Criterion Collection</a>. Both services are nearly technically identical: Monthly subscriptions that allow a customer to watch, from a vast catalog, a moving image on any of their devices at any moment. But, again, the numbers. Criterion is a: $33,000,000 / year business with 40 employees. Scale matters. No, Criterion won’t be producing <a href="https://www.theatlantic.com/technology/archive/2013/02/economics-netflixs-100-million-new-show/318706/">$100,000,000 TV shows</a>, but as a service, a company at their chosen scale, they can operate under a sustainable ethos of: <em>Deliver one amazing piece of classic, independent, or foreign film a week.</em><sup class="footnote-ref" id="fnref:publishing"><a href="#fn:publishing">10</a></sup></p>

<p>The contracts users enter into when using Criterion or Netflix manifest most clearly in design. Browsing Netflix is an endless sensation of falling forward into ever more content. Previews auto-play. As soon as one episode in a series ends, the next begins before credits finish rolling. If there’s no other episodes in the series, random trailers begin to play.</p>

<p>The very design of Netflix itself is constructed to reduce your ability to:</p>

<ol>
<li>think about what you want to do, or</li>
<li>step away from the service</li>
</ol>

<p>It’s designed to be a boundless slurry of content poured directly into your eyeballs. In a way, it’s <em>training</em> us to never step back or even consider, say, reading a book or going for a walk. The binge is dopaminergic to the max, satisfying the completionist instinct.</p>

<p>In breathless doublespeak, Hastings has said, &ldquo;Binge-watching is great because it puts you in control.&rdquo;</p>

<p>Take a moment to consider: The scale at which this system is operating, the original contract you felt you had entered into, and your relationship to and sense of contract with the service today.<sup class="footnote-ref" id="fnref:netflixchange"><a href="#fn:netflixchange">11</a></sup></p>

<p>Now go browse Criterion.</p>

<hr />

<p>There’s clearly value in both models. Netflix, in producing its <a href="https://en.wikipedia.org/wiki/List_of_original_programs_distributed_by_Netflix">infinitude of content</a> will invariably create some classics, give voice to folks who’ve yet to be voiced. And Criterion, in time, will help us wade through the muck for gems.</p>

<p>The publishing industry has similar analogs: Big publishers produce lightweight bestsellers, the profits from which find their way into more complex and challenging, less commercial books. However, the big difference is books (mostly) don&rsquo;t autoload themselves into your head; they require a constant opting-in on the part of the reader.</p>

<p>Worth noting: I don’t think a company like Netflix has to operate at its current extremes and could be more balanced; my example above may be somewhat binary, but companies can and do choose to occupy greyer zones.</p>

<p>The takeaway: The contract — emotionally, <em>physically</em> (bingeing is as much a physical decision as it is mental) — with Criterion is far simpler, clearer, and I&rsquo;d argue, healthier in the long term than the contract we currently enter into with Netflix.</p>

<hr />

<!--
“Media accounting” is a method of self-awareness. This kind of accounting is necessary for us to understand where objects like the book fit into contemporary life. Understanding the objective *contracts* into which we enter, how they may have come about, and how they're evolving helps us demystify why physical books (and, similarly, vinyl, analog film, et cetera) not only remain compelling, but become more compelling the more their digital twins grow vast and fuzzy.

----
-->

<h3 id="publishers-huh-what-are-they-good-for">Publishers, huh, what are they good for</h3>

<p>At Yale I was speaking to a bunch of publishers. So I proposed the following:</p>

<ul>
<li>Our goal as publishers should be: To make it easier for readers to choose the habit of (longform) reading.</li>
</ul>

<p>And then:</p>

<ul>
<li>The adversary of books is anything that eats attention — attention monsters.</li>
<li>The way to fight attention monsters is by helping potential readers habituate the very act of reading. </li>
</ul>

<p>Habits and identities are intertwined. Increased self-awareness around media contracts makes it easier to convert the <em>identities</em> of wanna-be readers into full-fledged bag-o-books readers. Our goal is not to get someone to read a single book, but <strong>become a reader</strong>.</p>

<p>That said: I have no idea how to reliably do that!</p>

<p>I can only share how I’ve converted myself into a more fervent reader:</p>

<p>I always have a Kindle Paperwhite in my bag. <a href="https://www.wired.com/story/future-book-is-here-but-not-what-we-expected/">I dislike much about this device.</a> It is a device of sadness, of <a href="https://medium.com/@craigmod/reconsidering-the-hardware-kindle-interface-3c54088bed9e">unrealized potential</a>. But, it is also a device (in my case) with a bunch of good, long form articles and books on it. The battery lasts for weeks. It is always in my bag because I never want an excuse to <em>not</em> engage with a long form piece of text. <strong>I want it to be as easy to reach for a book as it is to reach for my phone.</strong> I choose the Paperwhite because it&rsquo;s small and light.<sup class="footnote-ref" id="fnref:kindles"><a href="#fn:kindles">12</a></sup></p>

<p>In service to helping me read more books, I’ve also <a href="https://www.wired.com/story/six-weeks-100s-miles-hours-glorious-boredom-japan/">turned off all non-tool apps on my phone</a>. All I can do on my iPhone is check Google Maps, text, and read email. I use <a href="https://freedom.to">Freedom</a> to block all media, social and otherwise. Using this combination I’ve read more books this year than I have in the past three combined.</p>

<hr />

<h3 id="contracts-and-habits">Contracts and Habits</h3>

<p>James Clear’s book <a href="https://www.worldcat.org/title/atomic-habits-tiny-changes-remarkable-results-an-easy-proven-way-to-build-good-habits-break-bad-ones/oclc/1055766559"><em>Atomic Habits</em></a> has had a profound effect on the way I understand many of the patterns I&rsquo;ve constructed in my life over these last five years. I had intuited what was and wasn’t working, but Clear’s book gave me a framework for understanding why. You should read the entire thing.</p>

<p>Here are two big takeaways that are relevant to our contracts, attention monsters, and books discussion:</p>

<ol>
<li>True behavior change is identity change.</li>
<li>“Motion” is the act of researching; “action” is getting your reps in. Never mistake the two.</li>
</ol>

<p>James makes the argument that identity change (via an ever increasing belief in both your goal identity itself and the processes by which that identity is formed) happens as a cascade of incremental 1% changes in positive or negative directions. Opportunities for this percent change present themselves dozens of times a day. The best way to guarantee success is by preemptively engineering systems to reduce friction for positive habits, and increase friction for negative ones. Carrying a Kindle and blocking most media on my phone are two core pieces to my system of maintaining, believing in, and strengthening my identity as a “reader” and maintaining what I consider &ldquo;healthy&rdquo; contracts with apps and media.</p>

<hr />

<p>If habits define identity, then given the amount of time so many of us devote to reloading Twitter, opening Netflix, checking reddit, et cetera, are most of our identities that of media addict?</p>

<p>I suspect most folks reading this would <em>not</em> want to self-identify as an Instagram hope-to-be-influencer or Twitter combatant or Netflix binger. But most wouldn’t shy from self-identifying as, say, a reader.</p>

<p>We&rsquo;re amicable to calling ourselves readers for the same reason we want to identify as rock climbers or marathon runners or exceptional parents or selfless children or humanitarians or folks who’ve written thoughtful and considered books — because these activities carry with them an implicit sense of self-betterment, typified by being <em>active</em> (as opposed to passive).</p>

<p>To climb El Capitan requires dedication, discipline, focus — and yes, some insanity. To be a good child means taking care of a parent, calling, remembering, participating. The implied (and attractive) corollary of cultivating those qualities is that you’re a more perceptive, present human, experiencing and living life with a certain (healthy / obsessive) fullness.</p>

<hr />

<h3 id="reading-and-attention">Reading and Attention</h3>

<p>Sustained reading of long form texts and books is perhaps the most “active” of all basic media consumption. Philip Roth, in 2009, prognosticating the death of the novel, <a href="https://www.theguardian.com/lifeandstyle/2018/oct/14/the-lost-art-of-concentration-being-distracted-in-a-digital-world">smartly points out</a>:</p>

<blockquote>
<p>To read a novel requires a certain amount of concentration, focus, devotion to the reading. If you read a novel in more than two weeks you don&rsquo;t read the novel really. So I think that kind of concentration and focus and attentiveness is hard to come by – it&rsquo;s hard to find huge numbers of people, large numbers of people, significant numbers of people, who have those qualities.</p>
</blockquote>

<p>I love this: “If you read a novel in more than two weeks you don&rsquo;t read the novel really.” Meaning: To truly read (and, I might add, write) is to commit and maintain focus long enough to live fully within the world of the book (as opposed to ten second dips in and out, as we mostly do with much online media).</p>

<p><a href="https://www.worldcat.org/title/conversations-with-william-styron-monograph/oclc/862149835&amp;referer=brief_results">William Styron</a> put it well:</p>

<blockquote>
<p>A great book should leave you with many experiences, and slightly exhausted at the end.</p>
</blockquote>

<p>The critical insight is that deep reading is an <em>active</em> exhaustion, the result of <a href="https://www.espn.com/espn/story/_/id/27593253/why-grandmasters-magnus-carlsen-fabiano-caruana-lose-weight-playing-chess">burned calories,</a> not the passive exhaustion of an underused body and mind.</p>

<hr />

<p>Patterns among those of us who love reading and identify as “readers” show a continued predilection towards physical books. At Yale, <a href="https://www.penguinrandomhouse.com/about-us/management/">Nihar Malaviya</a>, executive vice president and chief operating officer for Penguin Random House U.S., put up a slide titled: “Formats have been shifting over the years — but have been somewhat stable recently.”</p>

<p>Of note:</p>

<ul>
<li>39% of Americans read only print books</li>
<li>29% read a mixture of digital and print</li>
<li>7% read digital-only</li>
<li>(24% simply don’t read)</li>
</ul>

<hr />

<p><img src="/roden/img/030/nihar.jpg" alt="Book reading trends" style="width: 100%; height: auto;" class="fullbleed" /></p>

<hr />

<p>There are likely a number of factors for this. An obvious one: Publishers deliberately set the price of digital books sometimes higher than physical books, especially with new releases. Or they set the price barely lower than the cost of a physical book. Because we perceive physical as having more implicit value (resaleability, for example) a rational consumer picks the physical edition over Kindle edition given the same price, doubly so given same or next day delivery (where the immediacy benefit of digital is nullified).</p>

<p>But I suspect there is also an unconscious bias growing towards <em>simpler contracts</em>. And a physical book provides the simplest contract of most media today. Simpler contracts often (but not always) mean that the object or app or piece of media has our best interests in mind (that&rsquo;s why the contract is simple; the befuddling nature of complex contracts is a feature for the company defining the contract, not a bug), simpler contracts make it easier for us to do “action” as opposed to “motion.”</p>

<p>James Clear’s definition of “motion” would include: Searching for books to read, queuing them up in the Kindle, getting samples, reading reviews. (Similarly: Fighting bots on Twitter, mindlessly bouncing around on YouTube via the algorithms.) These actions can trick us into thinking we&rsquo;re doing work when we aren&rsquo;t. Therefore it&rsquo;s not identity building; it&rsquo;s charlatanism to call yourself a reader if all you do is collect Kindle samples but never finish a book.</p>

<p>&ldquo;Action&rdquo; is <em>doing</em> the actual reading. And a paper book — because it is free from outside intrusions, especially compared to reading Kindle books on an iPad or iPhone — helps us succeed at this action component of identity building.</p>

<p>The hardware Kindle is not ideal, and Amazon itself (as almost any company operating at that scale) is ethically fraught, but in my case, I find significantly more value (i.e., the ability to perform &ldquo;action&rdquo;) in having a number of book options always with me (via a hardware Kindle) than carrying multiple physical books. If I only read physical books I wouldn’t read as much. When I finish a Kindle book I love, I almost always buy a physical copy to doubly support the author / publisher, and for archival + field-of-vision reference purposes.</p>

<hr />

<h3 id="the-ethics-of-books">The Ethics of Books</h3>

<p>One of the biggest adversaries of book publishing is attention monsters. And the collective goal of publishers should be to do everything they can to foster the habit of reading. Articulating and amplifying the benefits of reading would help convert non-readers into readers and help make the choice to engage in active media (vs passive media) 1% easier.</p>

<p>Because: There’s a broad <a href="https://www.theguardian.com/books/booksblog/2013/sep/16/reading-improves-childrens-brains">ethical argument</a> to be made for converting more of society into “active media” participants. (<a href="https://www.theatlantic.com/education/archive/2019/09/love-reading-books-leisure-pleasure/598315/">Done most effectively by showing children through parental example.</a> As I&rsquo;ve written many times before: Much of what we sense as being possible or impossible is based on nearby archetypes.)</p>

<p>In this essay I’ve been talking about books as the quintessence of &ldquo;active&rdquo; media, but I believe video (along with all other forms of media) can be made more active with healthier contracts; not all video has to devolve into lowest common denominator binge passivity.</p>

<p>The <a href="https://www.youtube.com/watch?v=FhwktRDG_aQ">Mr. Rogers documentary, “Won’t you be my Neighbor?”</a> is exemplary in casting light on how Fred Rogers saw the television as a vector for pedagogical amplification: teaching children goodness, kindness, emotional intelligence at scale. Access to high-quality educational programming has been shown to raise IQs. <a href="https://www.nytimes.com/2019/07/25/upshot/social-effects-television.html">Access to lower-quality programming has been shown to lower voter turnout.</a></p>

<hr />

<p>Choose active media, set yourself up to succeed by building systems to cultivate positive habits, but most importantly: Take a second to think about the contracts you’ve entered into as you go about your day. Are those contracts you’re happy with? Did you realize you had entered into them?</p>

<hr />

<p>Jia Tolentino’s opening piece in her most excellent <a href="https://www.worldcat.org/title/trick-mirror-reflections-on-self-delusion/oclc/1088603389?referer=di&amp;ht=edition"><em>Trick Mirror</em></a> takes us through how the web changed over the past twenty years:</p>

<blockquote>
<p>“At ten I was clicking around a web ring to check out other Angelfire sites. At twelve I was writing five hundred words a day on a public LiveJournal. At fifteen I was uploading photos of myself in a miniskirt on Myspace. By twenty-five, my job was to write things that would attract, ideally, a hundred thousand strangers per post. Now I’m thirty, and most of my life is inextricable from the internet, and its mazes of incessant forced connection — this feverish, electric, unlivable hell.”</p>
</blockquote>

<p>In reading between the lines of her essay: The contract changed, shifted slowly beneath us, until our work and lives became defined by something we don’t wholly understand, and never really opted into. The good news is that it’s all relatively early in this game. Dire as it may seem, none of these contracts are fait accompli. I believe we all have more autonomy than we may think.</p>

<hr />

<p>Sitting outside all of this digital contractual complexity is the simple, boring, blissfully inert physical book. Given its plainness, it may be the most magical of all our contemporary technologies. It exists simply to be still, cannot be optimized, will never know us, and though a body is still while reading, the mind is active, telepathy is happening, and a sense of self-betterment and hope pervades as we turn the final page.</p>

<hr />

<h4 id="noted">Noted:</h4>
<div class="footnotes">

<hr />

<ol>
<li id="fn:adapps">This isn&rsquo;t always true but is true often enough to warrant suspicion of any application that doesn&rsquo;t have a clear business model.
 <a class="footnote-return" href="#fnref:adapps">↩︎</a></li>
<li id="fn:venture">Venture capital is a powerful tool for accelerating market research in an attempt to find <a href="https://en.wikipedia.org/wiki/Product/market_fit">product:market fit</a>. Venture capital incentives become perverted when it&rsquo;s used to overtly or forcibly define markets, often in misalignment with market tendencies. One example of this perversion: Uber. A company for whom profitability on the long term is not guaranteed despite running through billions of dollars in venture capital. (They have a product:market fit, but not at a sustainable price, and with potentially nasty unintended consequences.) Tim O&rsquo;Reilly wrote an extensive piece about this very issue: <a href="https://qz.com/1540608/the-problem-with-silicon-valleys-obsession-with-blitzscaling-growth/">&ldquo;The fundamental problem with Silicon Valley’s favorite growth strategy&rdquo;</a>. It&rsquo;s easy to breathlessly condemn VC. But overall, venture capital is no more inherently amoral than a hammer. The vilification of venture capital is often based more in political fashion than fact. (But yes, <a href="https://www.bloomberg.com/news/articles/2019-10-22/neumann-clings-to-billionaire-status-after-wework-gets-a-bailout">We(Work)</a>) is a total debacle and apotheosis of venture charlatanism; thankfully public market vetting was smarter than Softbank.)
 <a class="footnote-return" href="#fnref:venture">↩︎</a></li>
<li id="fn:bigloops">I&rsquo;ve worked to <a href="https://craigmod.com/essays/sms_publishing/">build software and run experiments</a> with &ldquo;big&rdquo; loops — that is loops that span weeks or months or years, not the standard seconds or minutes of most apps.
 <a class="footnote-return" href="#fnref:bigloops">↩︎</a></li>
<li id="fn:founders">It should be noted that even the founders of these initially benign apps self-delude. When Instagram sold to Facebook they were promised sovereignty. No company pays $1B to allot the acquisition target eternal sovereignty (this is both nonsensical and somewhat amoral of the company in the context of public markets — the duty of Facebook in this deal is to increase shareholder value, not to be altruistic towards the Instagram community (although those two interests are not mutually exclusive); companies issue the promise of sovereignty to get the deal done. (Much of the work of being a CEO is convincing talented people that illiquid stock options are edible.) And Instagram <em>did</em> have a few years of relative internal independence, that is until Facebook needed them to make more money, causing <a href="https://www.theverge.com/interface/2019/4/17/18411363/why-instagram-founders-quit-hamburger-button-location-tracking">both co-founders to run off</a>.
 <a class="footnote-return" href="#fnref:founders">↩︎</a></li>
<li id="fn:adsok">This is not to say all ads are bad ads. There is certainly a medium-ground of ads and subscriptions. In fact, that might be the ideal, since not everyone can afford a subscription. Medium, for example, excised all of its ads in 2017, laying off much of the sales staff, in favor of going all in on subscriptions. I think the motives here — to exist in a &ldquo;pure&rdquo; space unsullied by advertising is admirable, but in the case of this company, a more metered shift between ads and subscriptions may have been instructive for the industry as a whole.
 <a class="footnote-return" href="#fnref:adsok">↩︎</a></li>
<li id="fn:unintendedcontracts">Related: <a href="https://www.nytimes.com/2019/11/04/business/secret-consumer-score-access.html">Most all of our interactions are being sold or quantified in some way or another</a>.
 <a class="footnote-return" href="#fnref:unintendedcontracts">↩︎</a></li>
<li id="fn:streaming">Or almost any streaming app; I&rsquo;m using Netflix here as an example because Hastings has been the most vocal about their Total Content Domination goals.
 <a class="footnote-return" href="#fnref:streaming">↩︎</a></li>
<li id="fn:netflix">Netflix has some great shows. Have you seen <a href="https://www.nytimes.com/interactive/2018/10/04/magazine/good-place-michael-schur-philosophy.html">&ldquo;The Good Place?&rdquo;</a> You should. I’ve been a Netflix subscriber for years, and rented DVDs from them almost two decades ago. But ignore the output for a second and let’s just look at the numbers — the 30,000 ft view — to try and understand the media accounting going on and why the company may operate as it does.
 <a class="footnote-return" href="#fnref:netflix">↩︎</a></li>
<li id="fn:appletv">Apple TV+ is worth considering for a second because, for Apple, streaming is (for now) an extremely tiny value add to the company&rsquo;s other much larger revenue streams. Hence, you&rsquo;ll never hear Apple talk about &ldquo;competing&rdquo; with sleep. The implicit contract we enter with Apple TV+ is almost comically light-touch compared to Netflix becuase the market dynamics make it low-stakes for Apple.
 <a class="footnote-return" href="#fnref:appletv">↩︎</a></li>
<li id="fn:publishing">To draw parallels to the publishing industry, Criterion is a <a href="https://coffeehousepress.org/">Coffee House</a> or <a href="https://www.graywolfpress.org/">Graywolf</a> or <a href="https://tinhouse.com/">Tin House</a> kind of operation. These are the publishers for whom explicit profits are not the driving force, and because of that, we readers, are gifted strange, delightful, and challenging literature.
 <a class="footnote-return" href="#fnref:publishing">↩︎</a></li>
<li id="fn:netflixchange">20 years ago: Watch a great movie on DVD every now and then; 8 years ago: Watch a great movie on streaming once or twice a month; today: Binge a television series a week.
 <a class="footnote-return" href="#fnref:netflixchange">↩︎</a></li>
<li id="fn:kindles">The Oasis, ostensibly Amazon&rsquo;s premier ebook reader is designed in such a way, with such proportions, as to fit into no average pocket. It also manages to sit oddly in the hand. Though the screen is nicer — the material covering it seems to be less fingerprint prone than the Paperwhite — the Paperwhite is far less precious, better proportioned, fits in almost any pocket and I find it to be much easier to hold. Although I&rsquo;d happily pay a premium, in classic Amazon goofery, the premium experience is less premium than the cheaper alternative.
 <a class="footnote-return" href="#fnref:kindles">↩︎</a></li>
</ol>
</div>

