title: A commentary of Wiio's laws
url: https://www.cs.tut.fi/~jkorpela/wiio.html
hash_url: cf5d1c3b5e636207d12235a42f191e26

<h1>How all human communication fails, except by accident,
<br/>
<small>or a commentary of <span lang="fi">Wiio</span>'s laws</small></h1>

<p class="summary"><span lang="fi">Wiio</span>'s laws
 are humoristically formulated
serious observations about how <em>human communication usually fails except
by accident</em>. This document comments on the applicability and
consequences of the laws, especially as regards to communication on
the Internet.</p>



<p>Finnish original: <i lang="fi">Viestintä yleensä epäonnistuu,
paitsi sattumalta.</i></p>

<p>This is the fundamental one among <span lang="fi">Wiio</span>'s
 laws; others are
corollaries from it, examples of it, or vaguely related notes. It
is easy to see the relationship between it and
<a href="http://dmawww.epfl.ch/roso.mosaic/dm/murphy.html" title="Murphy's laws and corollaries">Murphy's law(s)</a> (see also:
<cite><a href="http://www.monitor.hr/matija/murphy/0001567/download/edition.htm">The Complete Edition of Murphy's Laws</a></cite>)
and it
easy to see as just a humorously pessimistic expression of feelings
caused by some specific failures, strengthened by pessimistic
people's tendency to remember failures better than successes.</p>

<p class="important">Despite being entertaining, <span lang="fi">Wiio</span>'s laws are
valid observations about <em>all</em> human communication. For any
constructive approach to communication, we need to <em>admit</em>
their truth and build upon them, instead of comfortably exercizing
illusionary communication.</p>

<p>Perhaps
<a href="#who" title="About professor Osmo A. Wiio">prof. <span lang="fi">Wiio</span></a>
did not mean quite this. That would just prove
<a href="#3" title="There is always someone who knows better than you what you meant with your message">law 3</a>.
And if he did, that would provide an
additional example of the very <a href="#1" title="Communication usually fails, except by accident">law 1</a>,
since people who have read about the laws seem to take them
as sarcastic humour <em>only</em>.
</p>

<p>The law is to be interpreted as relating to <em>human</em>
communication. Communication between computers (and animals) works
often quite well. Human communication uses <em>vaguely defined
<strong>symbols</strong></em>. It has often been said, quite
appropriately, that it is the <dfn>use of
symbols</dfn>, i.e. the ability
to define
<a href="http://webserver.maclab.comp.uvic.ca/writersguide/Pages/RhetSymbol.html" title="What is a symbol (e.g. as opposite to a sign)">symbols</a>
for permanent or casual use, that
separates man from (other) animals. It is also the thing that makes
human communication fail, as a rule.</p>

<p>One reason to that is that by being conventional by their very essence,
<em>symbols are prone to misunderstanding</em>. You use a word thinking it
has a specific meaning by a convention; but the recipient of your message
applies a different convention; what's worse, you usually have no way
of knowing that.

</p><p class="deem">A symbol is essentially a sign to which some meaning
is <em>assigned by convention</em> rather than by any external
similarity between the sign and its denotation.
Thus, for example, a word like <i>lion</i> is a symbol: the word
does not resemble a lion. An onomatopoetic word like <i>whizzle</i>
is not a pure symbol in the same sense. And a <em>picture</em>,
even a very stylicized picture, of a lion is not a symbol for a lion
in the sense discussed here.
A symbol like the word <i>lion</i> may sound very simple and unambiguous.
But think about the various <em>connotations</em>. You perhaps meant just the lion,
<i lang="la">Panthera leo</i>, as an animal species; the recipient may have
taken it as a symbol of strength, or bravery, or danger, depending on
his cultural and personal background. Perhaps the recipient has read
the
<a href="http://cslewis.drzeus.net/" title="Into the Wardrobe: The C. S. Lewis Web Site">Narnia</a>
books with great enthusiasm; or perhaps a lion
has killed a friend of his.
</p>
<p>Let us list some <em>examples</em> of why human communication fails:
</p><ul>
<li> <strong>Language differences</strong>. On the Internet, for example,
<a href="lingua-franca.html">the <i>lingua franca</i> is badly
     written and poorly understood English</a>.
Some people use it as their native language; other learned some of it
from various sources. In any case, whatever you say will be interpreted in
a myriad of ways, whether you use idiomatic English or not.
</li><li> <strong>Cultural differences</strong>. Whatever you assume about the recipients
of your message, the wider the audience, the more of them will fail to
meet your assumptions.
On the Internet, this
virtually guarantees you will be misunderstood.
What you intend to say as a neutral matter of fact
will be interpreted 
(by different people)
as a detestable political opinion, a horrendous blasphemy, and
a lovely piece of poetry.
</li><li> <strong>Personal differences</strong>. Any assumption about the prior knowledge on the
subject matter fails for any reasonably large audience.
Whatever you try to explain about the genetics of colors will be
incomprehensible to most people, since they have a very vague idea of 
what "genes" are
(in <em>written</em> communication you might just manage to distinguish
them from Jeans),
and "dominance" is just Greek or sex to them.
</li><li> Just having some <strong>data lost</strong>. The listener does not pay attention
at a critical moment, and he misses something indispensable. In the worst,
and usual, case he does not know he missed it.
</li></ul>

<p>
Remember that <strong>the laws of statistics are against you</strong>: even if the 
probabilities of failures were small when taken individually (they aren't),
for success you would need a situation where <em>none</em> of them happens.
A single misunderstanding in any essential area destroys the message.
If you know some arithmetics, you can see that the odds are really against you.
Just take a simple example where communication can fail for twenty different
reasons (which is a huge underestimate). Assuming that the probability of failure
is just 0.1 for each of them (unrealistically optimistic), calculations show
that you'll succeed with the probability (1-0.1) to the power 20,
which is about 12%.</p>

<p>Things are actually much worse. The discussion above is based on
a <em>simplistic model of communication</em> which is very popular,
and often taken as self-evident.
That model could be characterized as <dfn>teaching by feeding</dfn>:
there's a teacher (someone who communicates) and a pupil (a recipient
of communication), and communication is a process of <em>transferring</em>
some information from the teacher's mind in the pupil's mind.
At the extreme, this means making the pupil <em>memorize</em> what
the teacher says or a text in a book.
The difficulty of communication would then consist basically just of
the <em>noise</em> in the line of communication.
</p>

<p><a name="chain">In reality,
<strong>communication is much more complicated and diffuse.</strong></a>
Consider a <em>simple</em> case where someone (<var>A</var>)
is explaining to someone else (<var>B</var>)
how to find a particular place; and assume that they speak the same
language and nothing in the environment disturbs the communication;
and assume that <var>A</var> really knows the way.
To communicate, <var>A</var> must <strong>convert</strong> his knowledge,
which is something invisible and intangible in his <em>mind</em>, into
words, drawings, gestures, or whatever means he is about to use.
It is the visible and audible data that gets "transferred"
(<em>if</em> it gets - remember that this is a simplified case).
Then <var>B</var> tries to process that data and construct a mental model
of what he has to do to reach the place.
It would be very naïve to assume that this process is simply the
reversal of the process that took place when <var>A</var> formulated
the message.</p>

<p class="important">This can be presented diagrammatically as follows:<br/>
<strong>idea in <var>A</var>'s mind --&gt; a formulated message (e.g. sentence)
--&gt; transfer mechanism (e.g. speech and hearing)
--&gt; idea in <var>B</var>'s mind</strong><br/>
Each transformation (depicted as "--&gt;") brings its own contribution
to the probability of a failure.
</p>
<p><a name="transl">When communication takes place through
a <strong>translation</strong></a>, serious additional complications
are caused. Quite often translations are made incompetently or
sloppily in a haste. But even the most competent and careful
translator is an additional component of <a href="#chain">the chain</a>
and inevitably distorts the message more or less.
Professional translators often demonstrate
<a href="#3" title="There is always someone who knows better than you what you meant with your message">law 3</a> well. In fact, they might even think they <em>should</em>
"improve" the message instead of doing that by accident or by
necessity (e.g. the necessity of adding interpretation to the message
due to lack of sufficiently indefinite words in the target language).
</p>
<p>So it's not just a matter of <em>components</em> of a message
being in great danger of getting corrupted - words misheard,
gestures misinterpreted, sentence constructs misparsed and so on.
In our simple example, even if <var>B</var> gets all components of
the message correctly, he needs to merge them with the information
he already has. If the instructions begin with "go to the bus station",
he needs to know how to get there first.
In the worst case, he thinks he knows that well but doesn't.
If the message contains an instruction to drive straight ahead,
<var>B</var> will be really puzzled when the road bifurcates
in a Y-like manner. (It was always clear to <var>A</var> what driving
straight ahead means there.)
All messages are
unavoidably <em>incomplete</em>:
in order to be of finite length,
they must presume some prior
knowledge in the recipient's side.
(In fact, even if your message told everything, it wouldn't help;
the recipient forgets what has read as he reads forward.)
Presuming means guessing, more or less.
By accident, you might guess right.
</p>
<p>But it's not just the "teacher" that guesses wrong and omits
indispensable details. Quite often, and very regularly e.g. in
people's cries for help on
<a href="usenet/index.html" title="Material about Usenet (&quot;newsgroups&quot;) by Jukka Korpela">Usenet</a>, the person who needs information formulates his question
so that no meaningful answer is possible. "Please help me, my computer
is broken!"
And the questioner often <em>implies a specific approach</em> to
solving his ultimate problem and asks how to solve a <em>technical</em>
problem; it usually happens that the technical problem is unsolvable
(the approach leads to a dead end), but how can anyone help when
the real question hasn't even been asked?
</p>



<p>Finnish original: <i lang="fi">Jos viestintä voi epäonnistua,
niin se epäonnistuu.</i></p>

<p>The factors that can make human communication fail might not be
very serious, when each of them is taken in isolation. However,
there are so many risks and they can <em>interact</em> in so many
ways that it is statistically almost certain that
communication fails.

</p>

<p>Finnish original: <i lang="fi">Jos viestintä ei voi epäonnistua,
niin se kuitenkin tavallisimmin epäonnistuu.</i></p>

<p>Even if you pay great attention to make your communication
unambiguous, effective, and understandable,
there will still be too many risks you haven't taken care of.
Moreover, your measures are at best functional most of the time,
which means that the combined probability for your communication
to fail in at least <em>one</em> one of the ways in which it could fail
is higher than you dare to imagine.</p>



<p>Finnish original: <i lang="fi">Jos viestintä näyttää onnistuvan
toivotulla tavalla, niin kyseessä on väärinkäsitys.</i></p>

<p>When communication seems to be simple, easy and successful, it's probably
a total failure. The recipient looks happy and thankful, because
he understood your message <em>his</em> way, which is what he likes, and 
very different from what you were actually saying.</p>

<p>An old <a href="usenet/index.html" title="Material about Usenet">Usenet</a> saying tells us that to every complex
question, there is an answer which is simple, understandable, and pleasant,
and plain wrong. People love to accept simple answers; only later do they
realize they were wrong. More harmfully, many wrong answers have the nasty
feature of "working" at first sight. It's much more harmful to get such an
answer than to get an answer which turns out to be bogus the first time
you try it.</p>



<p>Finnish original: <i lang="fi">Jos itse olet sanomaasi
tyytyväinen, niin viestintä varmasti epäonnistuu.</i></p>

<p>Being content with the formulation of your message is a sure
sign of having formulated it for <em>yourself</em>.</p>



<p>Finnish original: <i lang="fi">Jos sanoma voidaan tulkita eri
tavoin, niin se tulkitaan tavalla, josta on eniten
vahinkoa.</i></p>

<p>This Murphyistic remark is a warning about the very real possibility
that ambiguities will be resolved in just the way you did not mean.
Notice that this does not mean the worst misunderstanding you can
imagine; rather, something worse - an interpretation you could
not have imagined when you formulated your message.</p>



<p>Finnish original: <i lang="fi">On olemassa aina joku, joka
tietää sinua itseäsi paremmin, mitä olet sanomallasi
tarkoittanut.</i></p>

<p>People who understand you can be a real nuisance.
It might take some time before you see that they completely failed
to see what you meant, but that does not prevent them for propagating
their ideas as yours.</p>



<p>Finnish original: <i lang="fi">Mitä enemmän viestitään, sitä
huonommin viestintä onnistuu.</i></p>

<p>There's a widespread superstition that the more you communicate the
better. In reality, increasing the amount of communication
most probably just causes more misunderstandings.</p>

<p>There are people who keep repeating that there can't be too much
information. Whether that's literally true is debatable. What what they
<em>mean</em> (cf. to <a href="#3" title="There is always someone who knows better than you what you meant with your message">law 3</a>) is just plain wrong. There can be, and there is, too large
a <em>volume of messaging</em>. Data does not equal information.</p>



<p>Finnish original: <i lang="fi">Mitä enemmän viestitään, sitä
nopeammin väärinkäsitykset lisääntyvät.</i></p>

<p>In addition to reformulating <a href="#4">law 4</a>, this
refers to the fact that
<em>repetition strengthens false ideas</em>. When people see the same
message repeated over and over again, they usually start believing it.
Even if your message happened to be true, they misunderstood it, so
what they actually believe is not what you meant. And since the message
has been presented so strongly, they tell it to their friends,
who propagate it further, etc.
Naturally,
in that process, it gets distorted more and more.</p>



<p>Finnish original: <i lang="fi">Joukkoviestinnässä ei ole
tärkeätä se, miten asiat ovat, vaan miten asiat näyttävät
olevan.</i></p>

<p>This law is just remotely related to
<a href="#1">the basic law</a>. It is however more and more important:
mass communication creates a world of its own, and people orient themselves
in that virtual world rather than the real one. After all, reality is
boring.

</p>

<p>Finnish original: <i lang="fi">Uutisen tärkeys on kääntäen
verrannollinen etäisyyden neliöön.</i></p>

<p>Even more remote to our main topic, this simply states that events
close to us look much more important to us than remote events.
When there is an aircraft accident, its importance in Finnish newspapers
basically depends on whether there were any Finns on board, not on the
number of people that died.</p>

<p>It is however relevant to <a href="#1">law 1</a> in the sense
that it <em>illustrates</em> one of the reasons why communication fails.
No matter what you say, people who receive your message will interpret
and emphasize in their own <em>reference framework</em>.</p>



<p>Finnish original: <i lang="fi">Mitä tärkeämmästä tilanteesta on
kysymys, sitä todennäköisemmin unohdat olennaisen asian, jonka
muistit hetki sitten.</i></p>

<p>Similarly to <a href="#6">law 6</a>, this illustrates one
of the causes of failures in communication.
It applies both to senders and recipients.
The recipient tends to forget relevant things, such as items which
have been emphatically presented in the message as necessary requirements
for understanding the rest of it.
And the sender, upon receiving a request for clarification, such as a question
during a lecture, will certainly be able to formulate an adequate, easy to
understand answer - <em>afterwards</em>, when the situation is over.



</p><hr title="Corollaries"/>

<h2><a name="cor1">Korpela's First Corollary:</a>
If nobody barks at you, your message did not get through</h2>

<p>Lack of negative feedback is often presented as indicating that
communication was successful.
<span lang="fr">Au contraire</span>, it really means you failed
miserably.</p>

<p>Since communication always fails, anyone who <em>does</em> understand
part of your message will miss the other parts. If he is motivated enough,
and understood well enough the part he understood,
he'll write back to you. Whether he barks at you or politely asks for
clarification is up to his education and character; for you, there should
be little difference.</p>

<p>Human communication works through dialogues. If something that <em>looks</em>
like one-directional communication, such as a book or a Web page or a newspaper
article, miraculously works, it's because the author participated in
dialogues elsewhere. He had discussed the topic with numerous people before
he wrote the "one-directional" message.</p>

<p>So feedback is not just getting some nice comments "keep up the good
work". Rather, <em>feedback as a genuinely interactive process is a
necessary part of human communication</em>. Feedback has emotional effects, too;
just getting <em>any</em> feedback is usually nice; but the <em>content</em>
matters too.</p>

<p>By statistical certainty, if you get sufficient feedback, there will
be negative feedback too. Even if your message is perfect, some people will
tell you it's crap. In fact, <em>especially if</em> it is perfect,
 some people
will say - often with harsh words -
it's no good, because there are clueless people who envy you.</p>

<p>Thus, lack of negative feedback indicates that few if any people really
cared about your message.</p>



<p>The Web used to contain a large amount of unorganized and unclassified data.
Now it contains a <em>huge</em> amount of unorganized and unclassified
data
and a jungle of "search engines", "catalogues" or "virtual libraries", and "portals".
</p><p>
The various searching tools have an immense impact. At best, they
are very clever and useful.
<a href="http://www.askjeeves.com">Ask Jeeves</a>, and you might
get an immediate answer to your question which you wrote in plain English.
Occasionally, it might even be a <em>correct</em> and utilizable answer.
</p><p>
It still remains a fact that when you are looking for information on the Web,
you'll find either nothing (when your search criteria are tight) or
a useless list of zillions of addresses (when your search criteria are generic).
Except by accident, that is.
</p><p>
The practical implication is that when searching for information, you
need to be <em>flexible and flighty</em>.
Learn to use a few searching tools well - that
means knowing well the search language of one or two search engines and using 
some well-maintained catalogues - but keep your eyes
open. Sometimes you need to learn to use new tools, and frequently you find
crucial information just by accident.
Searching for information on <var>X</var>,
you stumble across an essential resource on <var>Y</var>, which is among
your central interests too, but not the one you're thinking about now.
It might take some time to study it with some care - perhaps it's just
a resource to be added to your link list, but it might be much more important,
something that needs top priority in your dealing with <var>Y</var>.
<strong>Switch the context!</strong>
At the very minimum, store a pointer to information you've found, even if
that means doing something related to your hobbies during your working hours,
or, gasp, the opposite.
Remember that in searching for information, which is a peculiar form of
human communication, <em>accidents are your friends</em>, and perhaps the
only friends you've got.</p>



<p>Teaching is far more difficult than people think. At worst,
teaching is regarded as an one-directional transfer of information
to a recipient, much like feeding an animal or sending data to
a computer for storing. By the Laws, it will fail. Even if
the recipient receives something, it will be misunderstood.</p>

<p>At best, there's a continuous feedback cycle between the teacher and
the student. The latter sends back information that shows how he actually
understood the content. Although this communication generally fails, too, it
has sufficiently many odds of accidentally working. Moreover, it can be
a self-repairing process. When the student shows the teacher what he
has done, this will often indicate some fundamental misunderstandings.
Ideally, the teacher should try and help the user see what went wrong.</p>

<p>In non-interactive teaching, the situation is far more difficult.
The best the instructor can do is to provide guidance to
<em>self-testing</em>, via exercises and quizzes, or via material
that indirectly induces self-testing. In some cases, the student will
immediately see whether his exercise succeeds. Sometimes answers to
test questions need to be provided. And sometimes it is sufficient to
give the student just some ideas on how to try what he thinks he
has learned.</p>

<p>What should happen, then, is that when the student notices that
he does not pass a self-test, he gets back to the instructional
material, and tries to see what went wrong. At this phase,
additional material might prove out to be useful. Mostly any
"extra reading" is just ignored. But when the student realizes
that he fundamentally misunderstood something, he might be willing
to take extra trouble to read "secondary" material, which has now
become potentially primary to him. After all, if the main material
was not successful, it's probably time to study a presentation of 
the same topic in some other format and style.</p> 

<p>The important thing is to realize that even the best explanations
and illustrations will be misunderstood. The student needs a way
of testing his understanding against some criteria. At best,
this means <em>doing</em> something and seeing whether it works.</p>


<hr title="The constructive summary"/>
<p class="summary">As a constructive summary, we can just
state that you cannot communicate successfully. You can only
<strong>increase
the odds of accidental success</strong> by paying serious attention to
the problems discussed here.</p>

<hr title="About Osmo A. Wiio"/>
<p><a name="who">Professor <dfn lang="fi">Osmo
 <abbr title="Antero"><span title="Antero">
A.</span></abbr> Wiio</dfn> (born 1928) is a famous Finnish
researcher of human communication.</a>
He has studied, among other
things, readability of texts, organizations and communication
within them, and the general theory of communication. In addition
to his academic career, he has authored books, articles, and radio
and TV programs on technology, the future, society, and politics.
He formulated "<span lang="fi">Wiio</span>'s laws"
 when he was a member of parliament
(1975--79)
and published them in
<cite lang="fi">Wiion lait - ja vähän muidenkin</cite>
(<span lang="fi">Wiio's</span> laws - and some others'; in Finnish).
(<span lang="sv">Weilin</span>+<span lang="fi">Göös</span>,
 1978, <span lang="fi">Espoo</span>; ISBN 951-35-1657-1).
</p>

<hr title="Links"/>

<p>Related documents by other people:
</p>

<p>

See also
<a title="The Dilbert site, with a daily strip and a lot more" href="http://www.dilbert.com">the <cite>Dilbert</cite>
comics</a>, which often illustrate strikingly the ways in which
human communication fails, especially when related to hi tech.
In particular, communication between Dilbert and his boss
is guaranteed to fail, since the boss has no idea of the content
of the activities he "manages". 
</p>
